diff --git a/Classes/Hooks/PluginRenderer.php b/Classes/Hooks/PluginRenderer.php
index d094afb767c70a9dd8b1dd05720c86caa270137d..1f3bf83513cccfa40b51764a695317b1ab0aa974 100644
--- a/Classes/Hooks/PluginRenderer.php
+++ b/Classes/Hooks/PluginRenderer.php
@@ -23,6 +23,8 @@ namespace SGalinski\SgYoutube\Hooks;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Backend\View\PageLayoutView;
 use TYPO3\CMS\Backend\View\PageLayoutViewDrawItemHookInterface;
+use TYPO3\CMS\Core\Imaging\Icon;
+use TYPO3\CMS\Core\Imaging\IconFactory;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Form\Service\TranslationService;
 
@@ -107,18 +109,36 @@ class PluginRenderer implements PageLayoutViewDrawItemHookInterface {
 					$labelvalue
 				) . '</th>' . '</tr>';
 
 			// Table content rows
 			// Loop through plugin options
 			foreach ($pluginOptions['data']['sDEF']['lDEF'] as $key => $setting) {
+
 				// if plugin option exists within the Flexform configuration file
 				if (array_key_exists($key, $arrayJobs['sheets']['sDEF']['ROOT']['el'])) {
+
 					// Display label
 					$labelId = $arrayJobs['sheets']['sDEF']['ROOT']['el'][$key]['TCEforms']['label'];
 					$itemContent .= '<row>' . '<td><strong>' . $translationServiceObject->translate(
 							trim($labelId)
 						) . '</strong></td>';
+
 					// Display value
-					$itemContent .= '<td>' . $setting['vDEF'] . '</td>' . '</tr>';
+					// Show different icon for the 'Show API Result' field, depending on checkbox value
+					if ($key === 'settings.showApiResult') {
+						if ($setting['vDEF'] === '0') {
+							$itemContent .= '<td>' . GeneralUtility::makeInstance(IconFactory::class)->getIcon(
+									'actions-close', Icon::SIZE_SMALL
+								)
+									->render('inline') . '</td>' . '</tr>';
+						} else {
+							$itemContent .= '<td>' . GeneralUtility::makeInstance(IconFactory::class)->getIcon(
+									'actions-check', Icon::SIZE_SMALL
+								)
+									->render('inline') . '</td>' . '</tr>';
+						}
+					// Remaining values
+					} else {
+						$itemContent .= '<td>' . $setting['vDEF'] . '</td>' . '</tr>';
+					}
 				}
 			}
@@ -107,18 +109,36 @@ class PluginRenderer implements PageLayoutViewDrawItemHookInterface {
 				) . '</th>' . '</tr>';
 
-			// Table content rows
-			// Loop through plugin options
+			// Loop through plugin options and render rows
 			foreach ($pluginOptions['data']['sDEF']['lDEF'] as $key => $setting) {